@@ -8,12 +8,15 @@
 #include "imagesourcemodel.h"
 
 #include <QDebug>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logImageViewer)
 
 PathViewProxyModel::IndexInfo::IndexInfo(const IndexInfo &other)
-    : url { other.url }
-    , index { other.index }
-    , frameCount { other.frameCount }
-    , frameIndex { other.frameIndex }
+    : url { other.url },
+      index { other.index },
+      frameCount { other.frameCount },
+      frameIndex { other.frameIndex }
 {
 }
 
@@ -25,8 +28,8 @@ PathViewProxyModel::IndexInfo::IndexInfo(const IndexInfo &other)
     会自动在反方向插入数据，以达到在 PathView 中无缝切换图片的效果
  */
 PathViewProxyModel::PathViewProxyModel(ImageSourceModel *srcModel, QObject *parent)
-    : QAbstractListModel { parent }
-    , sourceModel(srcModel)
+    : QAbstractListModel { parent },
+      sourceModel(srcModel)
 {
     Q_ASSERT_X(nullptr != sourceModel, "init proxy model", "must contain source data");
 
@@ -50,12 +53,12 @@ QVariant PathViewProxyModel::data(const QModelIndex &index, int role) const
 
     auto infoPtr = indexQueue[index.row()];
     switch (role) {
-        case Types::ImageUrlRole:
-            return infoPtr ? infoPtr->url : QUrl();
-        case Types::FrameIndexRole:
-            return infoPtr ? infoPtr->frameIndex : 0;
-        default:
-            break;
+    case Types::ImageUrlRole:
+        return infoPtr ? infoPtr->url : QUrl();
+    case Types::FrameIndexRole:
+        return infoPtr ? infoPtr->frameIndex : 0;
+    default:
+        break;
     }
 
     return {};
@@ -97,7 +100,6 @@ bool PathViewProxyModel::setData(const QModelIndex &idx, const QVariant &value,
                     }
                 }
             }
-
         }
         return true;
     default:
@@ -158,32 +160,41 @@ void PathViewProxyModel::syncState()
  */
 void PathViewProxyModel::setCurrentSourceIndex(int sourceIndex, int frameIndex)
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::setCurrentSourceIndex() called with sourceIndex:" << sourceIndex << "frameIndex:" << frameIndex;
     if (indexQueue.isEmpty()) {
+        qCWarning(logImageViewer) << "indexQueue is empty, returning.";
         return;
     }
 
     DistanceType type = distance(sourceIndex, frameIndex);
+    qCDebug(logImageViewer) << "Calculated distance type:" << type;
 
     // 若跳转中途更新代理索引(打断当前动画)立即更新图片状态
     if (Current != type && Current != jumpFlag) {
+        qCDebug(logImageViewer) << "Jump in progress or current, refreshing both side data.";
         refreshBothSideData();
     }
 
     switch (type) {
-        case Previous:
-            movePrevoius();
-            break;
-        case Next:
-            moveNext();
-            break;
-        case OutOfRange:
-            // 触发跳转动画设置
-            jumpToIndex(sourceIndex, frameIndex);
-            break;
-        default:
-            // Current / Invalid
-            break;
+    case Previous:
+        qCDebug(logImageViewer) << "Distance type is Previous, moving previous.";
+        movePrevoius();
+        break;
+    case Next:
+        qCDebug(logImageViewer) << "Distance type is Next, moving next.";
+        moveNext();
+        break;
+    case OutOfRange:
+        qCDebug(logImageViewer) << "Distance type is OutOfRange, jumping to index.";
+        // 触发跳转动画设置
+        jumpToIndex(sourceIndex, frameIndex);
+        break;
+    default:
+        qCDebug(logImageViewer) << "Distance type is Current or Invalid, no action taken.";
+        // Current / Invalid
+        break;
     }
+    qCDebug(logImageViewer) << "PathViewProxyModel::setCurrentSourceIndex() finished.";
 }
 
 /**
@@ -192,13 +203,17 @@ void PathViewProxyModel::setCurrentSourceIndex(int sourceIndex, int frameIndex)
  */
 void PathViewProxyModel::movePrevoius()
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::movePrevoius() called.";
     // 同步 view 的当前位置
     setCurrentIndex(previousPorxyIdx(currentProxyIdx));
+    qCDebug(logImageViewer) << "Current proxy index after moving previous:" << currentProxyIdx;
 
     // 移动至前一张图片，附近的索引不变，右侧区间 - 1, 左侧区间 + 1
     int changeIndex = (currentProxyIdx + radius + 1) % maxCount;
     const IndexInfoPtr &baseInfo = indexQueue[nextProxyIdx(changeIndex)];
+    qCDebug(logImageViewer) << "Change index:" << changeIndex << "Base info URL:" << (baseInfo ? baseInfo->url.toString() : "null");
     updateIndexInfo(changeIndex, createPreviousIndexInfo(baseInfo));
+    qCDebug(logImageViewer) << "PathViewProxyModel::movePrevoius() finished.";
 }
 
 /**
@@ -207,12 +222,16 @@ void PathViewProxyModel::movePrevoius()
  */
 void PathViewProxyModel::moveNext()
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::moveNext() called.";
     setCurrentIndex(nextProxyIdx(currentProxyIdx));
+    qCDebug(logImageViewer) << "Current proxy index after moving next:" << currentProxyIdx;
 
     int changeIndex = (currentProxyIdx + radius) % maxCount;
     const IndexInfoPtr &baseInfo = indexQueue[previousPorxyIdx(changeIndex)];
+    qCDebug(logImageViewer) << "Change index:" << changeIndex << "Base info URL:" << (baseInfo ? baseInfo->url.toString() : "null");
 
     updateIndexInfo(changeIndex, createNextIndexInfo(baseInfo));
+    qCDebug(logImageViewer) << "PathViewProxyModel::moveNext() finished.";
 }
 
 /**
@@ -221,32 +240,42 @@ void PathViewProxyModel::moveNext()
  */
 void PathViewProxyModel::resetModel(int sourceIndex, int frameIndex)
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::resetModel() called with sourceIndex:" << sourceIndex << "frameIndex:" << frameIndex;
     beginResetModel();
+    qCDebug(logImageViewer) << "Begin reset model.";
 
     // 无需通知
     currentProxyIdx = 0;
     jumpFlag = Current;
     indexQueue.clear();
     indexQueue.append(infoFromIndex(sourceIndex, frameIndex));
+    qCDebug(logImageViewer) << "Index queue initialized with first item:" << (indexQueue.first() ? indexQueue.first()->url.toString() : "null");
 
     QList<IndexInfoPtr> prependQueue;
 
     while ((indexQueue.size() + prependQueue.size()) < maxCount) {
+        qCDebug(logImageViewer) << "Filling index queue. Current queue size:" << indexQueue.size() << "Prepend queue size:" << prependQueue.size();
         // 首次进入时，前面的节点不填充，而是追加到尾部，保证首张图片索引指向 0
         if (prependQueue.isEmpty()) {
             prependQueue.prepend(createPreviousIndexInfo(indexQueue.first()));
+            qCDebug(logImageViewer) << "Prepended first previous index info.";
         } else {
             prependQueue.prepend(createPreviousIndexInfo(prependQueue.first()));
+            qCDebug(logImageViewer) << "Prepended previous index info.";
         }
 
         // 区间右侧数据直接填充
         indexQueue.append(createNextIndexInfo(indexQueue.last()));
+        qCDebug(logImageViewer) << "Appended next index info.";
     }
 
     // 追加区间左侧的数据
     indexQueue.append(prependQueue);
+    qCDebug(logImageViewer) << "Appended prepend queue. Final queue size:" << indexQueue.size();
 
     endResetModel();
+    qCDebug(logImageViewer) << "End reset model.";
+    qCDebug(logImageViewer) << "PathViewProxyModel::resetModel() finished.";
 }
 
 /**
@@ -254,48 +283,65 @@ void PathViewProxyModel::resetModel(int sourceIndex, int frameIndex)
  */
 void PathViewProxyModel::deleteCurrent()
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::deleteCurrent() called.";
     if (indexQueue.isEmpty()) {
+        qCWarning(logImageViewer) << "indexQueue is empty, returning.";
         return;
     }
 
     // 特殊处理，此时源数据无文件
     if (0 == sourceModel->rowCount()) {
+        qCDebug(logImageViewer) << "Source model row count is 0, resetting model.";
         beginResetModel();
         setCurrentIndex(0);
         indexQueue.clear();
         endResetModel();
+        qCDebug(logImageViewer) << "Model reset after source model empty.";
         return;
     }
 
     const IndexInfoPtr &current = indexQueue[currentProxyIdx];
     if (!current) {
+        qCWarning(logImageViewer) << "Current index info is null, returning.";
         return;
     }
+    qCDebug(logImageViewer) << "Current image to delete:" << current->url.toString() << "at source index:" << current->index;
 
     // 源数据模型移除当前图片，默认将后续图片前移，currentIndex将不会变更，手动提示更新
     bool atEnd = (current->index >= sourceModel->rowCount());
     if (atEnd) {
+        qCDebug(logImageViewer) << "Deleting image at the end of source model.";
         // 获取之前的索引
         int previousIdx = previousPorxyIdx(currentProxyIdx);
+        qCDebug(logImageViewer) << "Previous proxy index:" << previousIdx;
 
         // 如果删除的是尾部数据，则索引会 - 1 . INT_MAX 会将帧索引指向尾帧
         auto previous = infoFromIndex(current->index - 1, INT_MAX);
         updateIndexInfo(previousIdx, previous);
+        qCDebug(logImageViewer) << "Updated previous index info.";
         // 更新完成数据后再更新界面，触发动画
         setCurrentIndex(previousIdx);
+        qCDebug(logImageViewer) << "Set current index to previous:" << previousIdx;
 
         // 更新当前索引后再更新两侧数据
         refreshBothSideData();
+        qCDebug(logImageViewer) << "Refreshed both side data.";
     } else {
+        qCDebug(logImageViewer) << "Deleting image not at the end of source model.";
         int nextIdx = nextProxyIdx(currentProxyIdx);
+        qCDebug(logImageViewer) << "Next proxy index:" << nextIdx;
         // NOTE: 源数据模型移除当前图片后，index不会变更
         auto next = infoFromIndex(current->index, 0);
         updateIndexInfo(nextIdx, next);
+        qCDebug(logImageViewer) << "Updated next index info.";
 
         setCurrentIndex(nextIdx);
+        qCDebug(logImageViewer) << "Set current index to next:" << nextIdx;
 
         refreshBothSideData();
+        qCDebug(logImageViewer) << "Refreshed both side data.";
     }
+    qCDebug(logImageViewer) << "PathViewProxyModel::deleteCurrent() finished.";
 }
 
 /**
@@ -304,12 +350,17 @@ void PathViewProxyModel::deleteCurrent()
  */
 void PathViewProxyModel::setQueueCount(int count)
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::setQueueCount() called with count:" << count;
     static int minLimit = 3;
     bool valid = (count >= minLimit) && !!(count % 2);
     Q_ASSERT(valid);
+    if (!valid) {
+        qCWarning(logImageViewer) << "Invalid queue count:" << count << ". Must be >= 3 and odd.";
+    }
 
     maxCount = count;
     radius = qFloor(maxCount / 2);
+    qCDebug(logImageViewer) << "maxCount set to:" << maxCount << ", radius set to:" << radius;
 }
 
 /**
@@ -317,18 +368,18 @@ void PathViewProxyModel::setQueueCount(int count)
  */
 void PathViewProxyModel::dumpInfo()
 {
-    qWarning() << "[ProxyModel] Currnet proxy index:" << currentProxyIdx;
+    qCDebug(logImageViewer) << "[ProxyModel] Current proxy index:" << currentProxyIdx;
     for (int i = 0; i < indexQueue.size(); ++i) {
         const IndexInfoPtr &info = indexQueue.at(i);
         if (info) {
-            qWarning() << QString("[ProxyModel] index: %1, count: %2, frameIndex: %3, Url: %4 %5")
-                              .arg(info->index)
-                              .arg(info->frameCount)
-                              .arg(info->frameIndex)
-                              .arg(info->url.toString())
-                              .arg((i == currentProxyIdx) ? "  <--" : "");
+            qCDebug(logImageViewer) << QString("[ProxyModel] index: %1, count: %2, frameIndex: %3, Url: %4 %5")
+                                               .arg(info->index)
+                                               .arg(info->frameCount)
+                                               .arg(info->frameIndex)
+                                               .arg(info->url.toString())
+                                               .arg((i == currentProxyIdx) ? "  <--" : "");
         } else {
-            qWarning() << QString("[ProxyModel] Empty index info");
+            qCDebug(logImageViewer) << "[ProxyModel] Empty index info at index:" << i;
         }
     }
 }
@@ -338,33 +389,43 @@ void PathViewProxyModel::dumpInfo()
  */
 void PathViewProxyModel::jumpToIndex(int sourceIndex, int frameIndex)
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::jumpToIndex() called with sourceIndex:" << sourceIndex << "frameIndex:" << frameIndex;
     const IndexInfoPtr &current = indexQueue[currentProxyIdx];
     if (!current) {
-        qWarning() << "No current data" << currentProxyIdx;
+        qCWarning(logImageViewer) << "No current data at index:" << currentProxyIdx;
         dumpInfo();
         return;
     }
 
+    qCDebug(logImageViewer) << "Jumping to index:" << sourceIndex << "frame:" << frameIndex
+                            << "from current:" << current->index << "frame:" << current->frameIndex;
+
     int jumpIndex = currentProxyIdx;
     DistanceType flag = Current;
     if (sourceIndex >= current->index && frameIndex >= current->frameIndex) {
         flag = Next;
         jumpIndex = nextProxyIdx(currentProxyIdx);
+        qCDebug(logImageViewer) << "Jump direction: Next. Jump index:" << jumpIndex;
     } else {
         flag = Previous;
         jumpIndex = previousPorxyIdx(currentProxyIdx);
+        qCDebug(logImageViewer) << "Jump direction: Previous. Jump index:" << jumpIndex;
     }
 
     // 更新跳转图片的源数据
     IndexInfoPtr jumpInfo = infoFromIndex(sourceIndex, frameIndex);
     updateIndexInfo(jumpIndex, jumpInfo);
+    qCDebug(logImageViewer) << "Updated jump index info for index:" << jumpIndex;
 
     // 触发跳转动画
     setCurrentIndex(jumpIndex);
+    qCDebug(logImageViewer) << "Set current index to jump index:" << jumpIndex;
 
     // currentIndex 的变更会判断 jumpFlag 触发 jumpFinished() ，
     // 因此 jumpFlag 的变更在 currentIndexChanged() 之后触发
     jumpFlag = flag;
+    qCDebug(logImageViewer) << "Jump flag set to:" << jumpFlag;
+    qCDebug(logImageViewer) << "PathViewProxyModel::jumpToIndex() finished.";
 }
 
 /**
@@ -372,23 +433,29 @@ void PathViewProxyModel::jumpToIndex(int sourceIndex, int frameIndex)
  */
 void PathViewProxyModel::refreshBothSideData()
 {
+    qCDebug(logImageViewer) << "Refreshing both sides of current index:" << currentProxyIdx;
     // 根据当前图片的位置，更新两侧半径的数据
     int previousIndex = currentProxyIdx;
     int nextIndex = currentProxyIdx;
 
     for (int i = 0; i < radius; ++i) {
+        qCDebug(logImageViewer) << "Refreshing side data, iteration:" << i;
         // 根据上此索引位置数据更新当前数据，中心向两侧增长
         IndexInfoPtr previousInfo = createPreviousIndexInfo(indexQueue[previousIndex]);
         previousIndex = previousPorxyIdx(previousIndex);
         updateIndexInfo(previousIndex, previousInfo);
+        qCDebug(logImageViewer) << "Updated previous index:" << previousIndex;
 
         IndexInfoPtr nextInfo = createNextIndexInfo(indexQueue[nextIndex]);
         nextIndex = nextProxyIdx(nextIndex);
         updateIndexInfo(nextIndex, nextInfo);
+        qCDebug(logImageViewer) << "Updated next index:" << nextIndex;
     }
 
     // 取消状态
     jumpFlag = Current;
+    qCDebug(logImageViewer) << "Jump flag reset to Current.";
+    qCDebug(logImageViewer) << "PathViewProxyModel::refreshBothSideData() finished.";
 }
 
 /**
@@ -396,36 +463,46 @@ void PathViewProxyModel::refreshBothSideData()
  */
 PathViewProxyModel::DistanceType PathViewProxyModel::distance(int sourceIndex, int frameIndex)
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::distance() called for sourceIndex:" << sourceIndex << "frameIndex:" << frameIndex;
     if (sourceIndex < 0 || sourceIndex >= sourceModel->rowCount()) {
+        qCDebug(logImageViewer) << "Source index out of range, returning Invalid.";
         return Invalid;
     }
 
     if (indexQueue.isEmpty()) {
+        qCDebug(logImageViewer) << "Index queue is empty, returning Invalid.";
         return Invalid;
     }
 
     const IndexInfoPtr &current = indexQueue[currentProxyIdx];
     if (!current) {
+        qCWarning(logImageViewer) << "Current index info is null, returning Invalid.";
         return Invalid;
     }
+    qCDebug(logImageViewer) << "Current item in proxy:" << current->url.toString() << "at index:" << current->index << "frame:" << current->frameIndex;
 
     int range = OutOfRange;
     int indexDis = sourceIndex - current->index;
+    qCDebug(logImageViewer) << "Index difference:" << indexDis;
     switch (indexDis) {
-        case Current:
-            range = frameIndex - current->frameIndex;
-            break;
-        case Previous: {
-            const IndexInfoPtr &previous = indexQueue[previousPorxyIdx(currentProxyIdx)];
-            if (previous) {
-                range = -(previous->frameCount - frameIndex) - current->frameIndex;
-            }
-        } break;
-        case Next:
-            range = current->frameCount - current->frameIndex + frameIndex;
-            break;
-        default:
-            break;
+    case Current:
+        qCDebug(logImageViewer) << "Index difference is Current.";
+        range = frameIndex - current->frameIndex;
+        qCDebug(logImageViewer) << "Frame difference:" << range;
+        break;
+    case Previous: {
+        qCDebug(logImageViewer) << "Index difference is Previous.";
+        const IndexInfoPtr &previous = indexQueue[previousPorxyIdx(currentProxyIdx)];
+        if (previous) {
+            range = -(previous->frameCount - frameIndex) - current->frameIndex;
+            qCDebug(logImageViewer) << "Previous frame count:" << previous->frameCount << ", new range:" << range;
+        }
+    } break;
+    case Next:
+        range = current->frameCount - current->frameIndex + frameIndex;
+        break;
+    default:
+        break;
     }
 
     // 判断范围
@@ -440,10 +517,14 @@ PathViewProxyModel::DistanceType PathViewProxyModel::distance(int sourceIndex, i
  */
 QUrl PathViewProxyModel::sourcePath(int sourceIndex)
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::sourcePath() called for sourceIndex:" << sourceIndex;
     if (0 <= sourceIndex && sourceIndex < sourceModel->rowCount()) {
-        return sourceModel->data(sourceModel->index(sourceIndex), Types::ImageUrlRole).toUrl();
+        QUrl path = sourceModel->data(sourceModel->index(sourceIndex), Types::ImageUrlRole).toUrl();
+        qCDebug(logImageViewer) << "Source path for index" << sourceIndex << ":" << path.toString();
+        return path;
     }
 
+    qCDebug(logImageViewer) << "Source index" << sourceIndex << "is out of range. Returning empty URL.";
     return {};
 }
 
@@ -453,7 +534,9 @@ QUrl PathViewProxyModel::sourcePath(int sourceIndex)
  */
 int PathViewProxyModel::previousPorxyIdx(int base)
 {
-    return (base - 1 + indexQueue.size()) % indexQueue.size();
+    int newIndex = (base - 1 + indexQueue.size()) % indexQueue.size();
+    qCDebug(logImageViewer) << "PathViewProxyModel::previousPorxyIdx() called for base:" << base << ", returning:" << newIndex;
+    return newIndex;
 }
 
 /**
@@ -462,7 +545,9 @@ int PathViewProxyModel::previousPorxyIdx(int base)
  */
 int PathViewProxyModel::nextProxyIdx(int base)
 {
-    return (base + 1) % indexQueue.size();
+    int newIndex = (base + 1) % indexQueue.size();
+    qCDebug(logImageViewer) << "PathViewProxyModel::nextProxyIdx() called for base:" << base << ", returning:" << newIndex;
+    return newIndex;
 }
 
 /**
@@ -471,14 +556,16 @@ int PathViewProxyModel::nextProxyIdx(int base)
  */
 PathViewProxyModel::IndexInfoPtr PathViewProxyModel::infoFromIndex(int sourceIndex, int frameIndex)
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::infoFromIndex() called for sourceIndex:" << sourceIndex << "frameIndex:" << frameIndex;
     QUrl url = sourcePath(sourceIndex);
     if (url.isEmpty()) {
+        qCWarning(logImageViewer) << "Empty URL for source index:" << sourceIndex;
         return {};
     }
 
     ImageInfo imageInfo(url);
     if (ImageInfo::Loading == imageInfo.status()) {
-        qWarning() << "Not ready image data";
+        qCDebug(logImageViewer) << "Image data not ready (status: Loading), will update asynchronously:" << url.toString();
         asyncUpdateLoadInfo(url, sourceIndex, frameIndex);
     }
 
@@ -487,6 +574,8 @@ PathViewProxyModel::IndexInfoPtr PathViewProxyModel::infoFromIndex(int sourceInd
     info->index = sourceIndex;
     info->frameCount = qMax(1, imageInfo.frameCount());
     info->frameIndex = qBound(0, frameIndex, info->frameCount - 1);
+    qCDebug(logImageViewer) << "Created IndexInfo: url=" << info->url.toString() << ", index=" << info->index
+                            << ", frameCount=" << info->frameCount << ", frameIndex=" << info->frameIndex;
 
     return info;
 }
@@ -497,42 +586,60 @@ PathViewProxyModel::IndexInfoPtr PathViewProxyModel::infoFromIndex(int sourceInd
  */
 void PathViewProxyModel::asyncUpdateLoadInfo(const QUrl &url, int sourceIndex, int frameIndex)
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::asyncUpdateLoadInfo() called for url:" << url.toString() << "sourceIndex:" << sourceIndex << "frameIndex:" << frameIndex;
     // 异步更新加载信息，一般仅初次加载存在此问题
     if (0 == frameIndex) {
+        qCDebug(logImageViewer) << "Starting async update for:" << url.toString()
+                                << "source index:" << sourceIndex;
         ImageInfo *delayInfo = new ImageInfo(url, this);
         connect(delayInfo, &ImageInfo::statusChanged, this, [this, delayInfo, sourceIndex]() {
+            qCDebug(logImageViewer) << "AsyncUpdateLoadInfo: ImageInfo status changed for:" << delayInfo->source().toString();
             // 仅更新加载成功的多页图数据，其它类型的数据无需关注，默认的 frameIndex 都是 0
             if (ImageInfo::Ready == delayInfo->status() && Types::MultiImage == delayInfo->type()) {
+                qCDebug(logImageViewer) << "Async update completed for multi-image:" << delayInfo->source().toString()
+                                        << "frames:" << delayInfo->frameCount();
                 auto current = indexQueue[currentProxyIdx];
                 if (!current) {
+                    qCWarning(logImageViewer) << "Current index info is null in async update, deleting delayInfo.";
                     delayInfo->deleteLater();
                     return;
                 }
 
                 if (sourceIndex == current->index) {
+                    qCDebug(logImageViewer) << "Source index matches current index, updating frame count and refreshing both sides.";
                     // 若为当前图片，仅需更新当前图片帧总数和两侧的数据
                     current->frameCount = delayInfo->frameCount();
                     refreshBothSideData();
                 } else if (sourceIndex < current->index) {
+                    qCDebug(logImageViewer) << "Source index is less than current index, updating previous indices.";
                     int previousIndex = currentProxyIdx;
                     for (int i = 0; i < radius; ++i) {
                         IndexInfoPtr previousInfo = createPreviousIndexInfo(indexQueue[previousIndex]);
                         previousIndex = previousPorxyIdx(previousIndex);
                         updateIndexInfo(previousIndex, previousInfo);
+                        qCDebug(logImageViewer) << "Updated previous index:" << previousIndex;
                     }
                 } else {
+                    qCDebug(logImageViewer) << "Source index is greater than current index, updating next indices.";
                     int nextIndex = currentProxyIdx;
                     for (int i = 0; i < radius; ++i) {
                         IndexInfoPtr nextInfo = createNextIndexInfo(indexQueue[nextIndex]);
                         nextIndex = nextProxyIdx(nextIndex);
                         updateIndexInfo(nextIndex, nextInfo);
+                        qCDebug(logImageViewer) << "Updated next index:" << nextIndex;
                     }
                 }
+            } else {
+                qCDebug(logImageViewer) << "Async update not for ready multi-image or frameIndex is not 0. Status:" << delayInfo->status() << "Type:" << delayInfo->type();
             }
 
             delayInfo->deleteLater();
+            qCDebug(logImageViewer) << "delayInfo deleted.";
         });
+    } else {
+        qCDebug(logImageViewer) << "Async update skipped for frameIndex:" << frameIndex << ". Only frameIndex 0 is processed.";
     }
+    qCDebug(logImageViewer) << "PathViewProxyModel::asyncUpdateLoadInfo() finished.";
 }
 
 /**
@@ -540,19 +647,25 @@ void PathViewProxyModel::asyncUpdateLoadInfo(const QUrl &url, int sourceIndex, i
  */
 PathViewProxyModel::IndexInfoPtr PathViewProxyModel::createPreviousIndexInfo(const IndexInfoPtr &baseInfo)
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::createPreviousIndexInfo() called.";
     if (!baseInfo) {
+        qCWarning(logImageViewer) << "Base info is null, returning empty IndexInfoPtr.";
         return {};
     }
 
     if (baseInfo->frameIndex > 0) {
         IndexInfoPtr previousFrame = IndexInfoPtr::create(*baseInfo);
         previousFrame->frameIndex--;
+        qCDebug(logImageViewer) << "Creating previous frame info. New frame index:" << previousFrame->frameIndex;
         return previousFrame;
     }
 
     IndexInfoPtr previous = infoFromIndex(baseInfo->index - 1);
     if (previous) {
         previous->frameIndex = previous->frameCount - 1;
+        qCDebug(logImageViewer) << "Creating previous image info. New frame index:" << previous->frameIndex;
+    } else {
+        qCDebug(logImageViewer) << "No previous image found for base index:" << baseInfo->index - 1;
     }
     return previous;
 }
@@ -562,13 +675,16 @@ PathViewProxyModel::IndexInfoPtr PathViewProxyModel::createPreviousIndexInfo(con
  */
 PathViewProxyModel::IndexInfoPtr PathViewProxyModel::createNextIndexInfo(const IndexInfoPtr &baseInfo)
 {
+    qCDebug(logImageViewer) << "PathViewProxyModel::createNextIndexInfo() called.";
     if (!baseInfo) {
+        qCWarning(logImageViewer) << "Base info is null, returning empty IndexInfoPtr.";
         return {};
     }
 
     if (baseInfo->frameCount - 1 > baseInfo->frameIndex) {
         IndexInfoPtr nextFrame = IndexInfoPtr::create(*baseInfo);
         nextFrame->frameIndex++;
+        qCDebug(logImageViewer) << "Creating next frame info. New frame index:" << nextFrame->frameIndex;
         return nextFrame;
     }
 
@@ -584,6 +700,7 @@ void PathViewProxyModel::updateIndexInfo(int proxyIndex, const IndexInfoPtr &inf
 {
     Q_ASSERT(0 <= proxyIndex && proxyIndex < indexQueue.size());
     indexQueue[proxyIndex] = info;
+    qCDebug(logImageViewer) << "Updated indexQueue at proxy index:" << proxyIndex;
 
     QModelIndex changeModelIndex = index(proxyIndex);
     Q_EMIT dataChanged(changeModelIndex, changeModelIndex, { Types::ImageUrlRole, Types::FrameIndexRole });
